@@ -28,18 +28,36 @@ def lint(ctx):
 @_invoke.task(_clean.py)
 def flake8(ctx):
     """ Run flake8 """
-    flake8 = ctx.shell.frompath('flake8')
-    if flake8 is None:
+    exe = ctx.shell.frompath('flake8')
+    if exe is None:
         raise RuntimeError("flake8 not found")
 
     with ctx.shell.root_dir():
         ctx.run(ctx.c(
             r''' %(flake8)s %(package)s.py ''',
-            flake8=flake8,
+            flake8=exe,
             package=ctx.package
         ), echo=True)
 
 
-@_invoke.task(lint, flake8, default=True)
-def all(ctx):
+@_invoke.task(_clean.py)
+def black(ctx):
+    """Run black"""
+    exe = ctx.shell.frompath('black')
+    if exe is None:
+        raise RuntimeError("black not found")
+
+    with ctx.shell.root_dir():
+        ctx.run(
+            ctx.c(
+                '%s --check --config black.toml .',
+                exe,
+                ctx.package.replace('.', '/'),
+            ),
+            echo=True,
+        )
+
+
+@_invoke.task(lint, flake8, black, default=True)
+def all(ctx):  # pylint: disable = redefined-builtin, unused-argument
     """ Run all """
